# autogenerated module
from typing import List, Optional

from ._schema import dataclass, field, DictMixin

from . import meta_v1


@dataclass
class FlowDistinguisherMethod(DictMixin):
    """FlowDistinguisherMethod specifies the method of a flow distinguisher.

      **parameters**

      * **type** ``str`` - `type` is the type of flow distinguisher method The supported types are
        "ByUser" and "ByNamespace". Required.
    """
    type: 'str'


@dataclass
class FlowSchema(DictMixin):
    """FlowSchema defines the schema of a group of flows. Note that a flow is made up
      of a set of inbound API requests with similar attributes and is identified by
      a pair of strings: the name of the FlowSchema and a "flow distinguisher".

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - `metadata` is the standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
      * **spec** ``Optional[FlowSchemaSpec]`` - `spec` is the specification of the desired behavior of a FlowSchema. More
        info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
      * **status** ``Optional[FlowSchemaStatus]`` - `status` is the current status of a FlowSchema. More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[FlowSchemaSpec]' = None
    status: 'Optional[FlowSchemaStatus]' = None


@dataclass
class FlowSchemaCondition(DictMixin):
    """FlowSchemaCondition describes conditions for a FlowSchema.

      **parameters**

      * **lastTransitionTime** ``Optional[meta_v1.Time]`` - `lastTransitionTime` is the last time the condition transitioned from one
        status to another.
      * **message** ``Optional[str]`` - `message` is a human-readable message indicating details about last
        transition.
      * **reason** ``Optional[str]`` - `reason` is a unique, one-word, CamelCase reason for the condition's last
        transition.
      * **status** ``Optional[str]`` - `status` is the status of the condition. Can be True, False, Unknown.
        Required.
      * **type** ``Optional[str]`` - `type` is the type of the condition. Required.
    """
    lastTransitionTime: 'Optional[meta_v1.Time]' = None
    message: 'Optional[str]' = None
    reason: 'Optional[str]' = None
    status: 'Optional[str]' = None
    type: 'Optional[str]' = None


@dataclass
class FlowSchemaList(DictMixin):
    """FlowSchemaList is a list of FlowSchema objects.

      **parameters**

      * **items** ``List[FlowSchema]`` - `items` is a list of FlowSchemas.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - `metadata` is the standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
    """
    items: 'List[FlowSchema]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class FlowSchemaSpec(DictMixin):
    """FlowSchemaSpec describes how the FlowSchema's specification looks like.

      **parameters**

      * **priorityLevelConfiguration** ``PriorityLevelConfigurationReference`` - `priorityLevelConfiguration` should reference a PriorityLevelConfiguration in
        the cluster. If the reference cannot be resolved, the FlowSchema will be
        ignored and marked as invalid in its status. Required.
      * **distinguisherMethod** ``Optional[FlowDistinguisherMethod]`` - `distinguisherMethod` defines how to compute the flow distinguisher for
        requests that match this schema. `nil` specifies that the distinguisher is
        disabled and thus will always be the empty string.
      * **matchingPrecedence** ``Optional[int]`` - `matchingPrecedence` is used to choose among the FlowSchemas that match a
        given request. The chosen FlowSchema is among those with the numerically
        lowest (which we take to be logically highest) MatchingPrecedence.  Each
        MatchingPrecedence value must be ranged in [1,10000]. Note that if the
        precedence is not specified, it will be set to 1000 as default.
      * **rules** ``Optional[List[PolicyRulesWithSubjects]]`` - `rules` describes which requests will match this flow schema. This FlowSchema
        matches a request if and only if at least one member of rules matches the
        request. if it is an empty slice, there will be no requests matching the
        FlowSchema.
    """
    priorityLevelConfiguration: 'PriorityLevelConfigurationReference'
    distinguisherMethod: 'Optional[FlowDistinguisherMethod]' = None
    matchingPrecedence: 'Optional[int]' = None
    rules: 'Optional[List[PolicyRulesWithSubjects]]' = None


@dataclass
class FlowSchemaStatus(DictMixin):
    """FlowSchemaStatus represents the current state of a FlowSchema.

      **parameters**

      * **conditions** ``Optional[List[FlowSchemaCondition]]`` - `conditions` is a list of the current states of FlowSchema.
    """
    conditions: 'Optional[List[FlowSchemaCondition]]' = None


@dataclass
class GroupSubject(DictMixin):
    """GroupSubject holds detailed information for group-kind subject.

      **parameters**

      * **name** ``str`` - name is the user group that matches, or "*" to match all user groups. See
        https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go
        for some well-known group names. Required.
    """
    name: 'str'


@dataclass
class LimitResponse(DictMixin):
    """LimitResponse defines how to handle requests that can not be executed right
      now.

      **parameters**

      * **type** ``str`` - `type` is "Queue" or "Reject". "Queue" means that requests that can not be
        executed upon arrival are held in a queue until they can be executed or a
        queuing limit is reached. "Reject" means that requests that can not be
        executed upon arrival are rejected. Required.
      * **queuing** ``Optional[QueuingConfiguration]`` - `queuing` holds the configuration parameters for queuing. This field may be
        non-empty only if `type` is `"Queue"`.
    """
    type: 'str'
    queuing: 'Optional[QueuingConfiguration]' = None


@dataclass
class LimitedPriorityLevelConfiguration(DictMixin):
    """LimitedPriorityLevelConfiguration specifies how to handle requests that are
      subject to limits. It addresses two issues:
       * How are requests for this priority level limited?
       * What should be done with requests that exceed the limit?

      **parameters**

      * **assuredConcurrencyShares** ``Optional[int]`` - `assuredConcurrencyShares` (ACS) configures the execution limit, which is a
        limit on the number of requests of this priority level that may be exeucting
        at a given time.  ACS must be a positive number. The server's concurrency
        limit (SCL) is divided among the concurrency-controlled priority levels in
        proportion to their assured concurrency shares. This produces the assured
        concurrency value (ACV) --- the number of requests that may be executing at a
        time --- for each such priority level:
                    ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
        bigger numbers of ACS mean more reserved concurrent requests (at the expense
        of every other PL). This field has a default value of 30.
      * **limitResponse** ``Optional[LimitResponse]`` - `limitResponse` indicates what to do with requests that can not be executed
        right now
    """
    assuredConcurrencyShares: 'Optional[int]' = None
    limitResponse: 'Optional[LimitResponse]' = None


@dataclass
class NonResourcePolicyRule(DictMixin):
    """NonResourcePolicyRule is a predicate that matches non-resource requests
      according to their verb and the target non-resource URL. A
      NonResourcePolicyRule matches a request if and only if both (a) at least one
      member of verbs matches the request and (b) at least one member of
      nonResourceURLs matches the request.

      **parameters**

      * **nonResourceURLs** ``List[str]`` - `nonResourceURLs` is a set of url prefixes that a user should have access to
        and may not be empty. For example:
          - "/healthz" is legal
          - "/hea*" is illegal
          - "/hea" is legal but matches nothing
          - "/hea/*" also matches nothing
          - "/healthz/*" matches all per-component health checks.
        "*" matches all non-resource urls. if it is present, it must be the only
        entry. Required.
      * **verbs** ``List[str]`` - `verbs` is a list of matching verbs and may not be empty. "*" matches all
        verbs. If it is present, it must be the only entry. Required.
    """
    nonResourceURLs: 'List[str]'
    verbs: 'List[str]'


@dataclass
class PolicyRulesWithSubjects(DictMixin):
    """PolicyRulesWithSubjects prescribes a test that applies to a request to an
      apiserver. The test considers the subject making the request, the verb being
      requested, and the resource to be acted upon. This PolicyRulesWithSubjects
      matches a request if and only if both (a) at least one member of subjects
      matches the request and (b) at least one member of resourceRules or
      nonResourceRules matches the request.

      **parameters**

      * **subjects** ``List[Subject]`` - subjects is the list of normal user, serviceaccount, or group that this rule
        cares about. There must be at least one member in this slice. A slice that
        includes both the system:authenticated and system:unauthenticated user groups
        matches every request. Required.
      * **nonResourceRules** ``Optional[List[NonResourcePolicyRule]]`` - `nonResourceRules` is a list of NonResourcePolicyRules that identify matching
        requests according to their verb and the target non-resource URL.
      * **resourceRules** ``Optional[List[ResourcePolicyRule]]`` - `resourceRules` is a slice of ResourcePolicyRules that identify matching
        requests according to their verb and the target resource. At least one of
        `resourceRules` and `nonResourceRules` has to be non-empty.
    """
    subjects: 'List[Subject]'
    nonResourceRules: 'Optional[List[NonResourcePolicyRule]]' = None
    resourceRules: 'Optional[List[ResourcePolicyRule]]' = None


@dataclass
class PriorityLevelConfiguration(DictMixin):
    """PriorityLevelConfiguration represents the configuration of a priority level.

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - `metadata` is the standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
      * **spec** ``Optional[PriorityLevelConfigurationSpec]`` - `spec` is the specification of the desired behavior of a "request-priority".
        More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
      * **status** ``Optional[PriorityLevelConfigurationStatus]`` - `status` is the current status of a "request-priority". More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#spec-and-status
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[PriorityLevelConfigurationSpec]' = None
    status: 'Optional[PriorityLevelConfigurationStatus]' = None


@dataclass
class PriorityLevelConfigurationCondition(DictMixin):
    """PriorityLevelConfigurationCondition defines the condition of priority level.

      **parameters**

      * **lastTransitionTime** ``Optional[meta_v1.Time]`` - `lastTransitionTime` is the last time the condition transitioned from one
        status to another.
      * **message** ``Optional[str]`` - `message` is a human-readable message indicating details about last
        transition.
      * **reason** ``Optional[str]`` - `reason` is a unique, one-word, CamelCase reason for the condition's last
        transition.
      * **status** ``Optional[str]`` - `status` is the status of the condition. Can be True, False, Unknown.
        Required.
      * **type** ``Optional[str]`` - `type` is the type of the condition. Required.
    """
    lastTransitionTime: 'Optional[meta_v1.Time]' = None
    message: 'Optional[str]' = None
    reason: 'Optional[str]' = None
    status: 'Optional[str]' = None
    type: 'Optional[str]' = None


@dataclass
class PriorityLevelConfigurationList(DictMixin):
    """PriorityLevelConfigurationList is a list of PriorityLevelConfiguration
      objects.

      **parameters**

      * **items** ``List[PriorityLevelConfiguration]`` - `items` is a list of request-priorities.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - `metadata` is the standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
    """
    items: 'List[PriorityLevelConfiguration]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class PriorityLevelConfigurationReference(DictMixin):
    """PriorityLevelConfigurationReference contains information that points to the
      "request-priority" being used.

      **parameters**

      * **name** ``str`` - `name` is the name of the priority level configuration being referenced
        Required.
    """
    name: 'str'


@dataclass
class PriorityLevelConfigurationSpec(DictMixin):
    """PriorityLevelConfigurationSpec specifies the configuration of a priority
      level.

      **parameters**

      * **type** ``str`` - `type` indicates whether this priority level is subject to limitation on
        request execution.  A value of `"Exempt"` means that requests of this priority
        level are not subject to a limit (and thus are never queued) and do not
        detract from the capacity made available to other priority levels.  A value of
        `"Limited"` means that (a) requests of this priority level _are_ subject to
        limits and (b) some of the server's limited capacity is made available
        exclusively to this priority level. Required.
      * **limited** ``Optional[LimitedPriorityLevelConfiguration]`` - `limited` specifies how requests are handled for a Limited priority level.
        This field must be non-empty if and only if `type` is `"Limited"`.
    """
    type: 'str'
    limited: 'Optional[LimitedPriorityLevelConfiguration]' = None


@dataclass
class PriorityLevelConfigurationStatus(DictMixin):
    """PriorityLevelConfigurationStatus represents the current state of a
      "request-priority".

      **parameters**

      * **conditions** ``Optional[List[PriorityLevelConfigurationCondition]]`` - `conditions` is the current state of "request-priority".
    """
    conditions: 'Optional[List[PriorityLevelConfigurationCondition]]' = None


@dataclass
class QueuingConfiguration(DictMixin):
    """QueuingConfiguration holds the configuration parameters for queuing

      **parameters**

      * **handSize** ``Optional[int]`` - `handSize` is a small positive number that configures the shuffle sharding of
        requests into queues.  When enqueuing a request at this priority level the
        request's flow identifier (a string pair) is hashed and the hash value is used
        to shuffle the list of queues and deal a hand of the size specified here.  The
        request is put into one of the shortest queues in that hand. `handSize` must
        be no larger than `queues`, and should be significantly smaller (so that a few
        heavy flows do not saturate most of the queues).  See the user-facing
        documentation for more extensive guidance on setting this field.  This field
        has a default value of 8.
      * **queueLengthLimit** ``Optional[int]`` - `queueLengthLimit` is the maximum number of requests allowed to be waiting in
        a given queue of this priority level at a time; excess requests are rejected.
        This value must be positive.  If not specified, it will be defaulted to 50.
      * **queues** ``Optional[int]`` - `queues` is the number of queues for this priority level. The queues exist
        independently at each apiserver. The value must be positive.  Setting it to 1
        effectively precludes shufflesharding and thus makes the distinguisher method
        of associated flow schemas irrelevant.  This field has a default value of 64.
    """
    handSize: 'Optional[int]' = None
    queueLengthLimit: 'Optional[int]' = None
    queues: 'Optional[int]' = None


@dataclass
class ResourcePolicyRule(DictMixin):
    """ResourcePolicyRule is a predicate that matches some resource requests, testing
      the request's verb and the target resource. A ResourcePolicyRule matches a
      resource request if and only if: (a) at least one member of verbs matches the
      request, (b) at least one member of apiGroups matches the request, (c) at
      least one member of resources matches the request, and (d) least one member of
      namespaces matches the request.

      **parameters**

      * **apiGroups** ``List[str]`` - `apiGroups` is a list of matching API groups and may not be empty. "*" matches
        all API groups and, if present, must be the only entry. Required.
      * **resources** ``List[str]`` - `resources` is a list of matching resources (i.e., lowercase and plural) with,
        if desired, subresource.  For example, [ "services", "nodes/status" ].  This
        list may not be empty. "*" matches all resources and, if present, must be the
        only entry. Required.
      * **verbs** ``List[str]`` - `verbs` is a list of matching verbs and may not be empty. "*" matches all
        verbs and, if present, must be the only entry. Required.
      * **clusterScope** ``Optional[bool]`` - `clusterScope` indicates whether to match requests that do not specify a
        namespace (which happens either because the resource is not namespaced or the
        request targets all namespaces). If this field is omitted or false then the
        `namespaces` field must contain a non-empty list.
      * **namespaces** ``Optional[List[str]]`` - `namespaces` is a list of target namespaces that restricts matches.  A request
        that specifies a target namespace matches only if either (a) this list
        contains that target namespace or (b) this list contains "*".  Note that "*"
        matches any specified namespace but does not match a request that _does not
        specify_ a namespace (see the `clusterScope` field for that). This list may be
        empty, but only if `clusterScope` is true.
    """
    apiGroups: 'List[str]'
    resources: 'List[str]'
    verbs: 'List[str]'
    clusterScope: 'Optional[bool]' = None
    namespaces: 'Optional[List[str]]' = None


@dataclass
class ServiceAccountSubject(DictMixin):
    """ServiceAccountSubject holds detailed information for service-account-kind
      subject.

      **parameters**

      * **name** ``str`` - `name` is the name of matching ServiceAccount objects, or "*" to match
        regardless of name. Required.
      * **namespace** ``str`` - `namespace` is the namespace of matching ServiceAccount objects. Required.
    """
    name: 'str'
    namespace: 'str'


@dataclass
class Subject(DictMixin):
    """Subject matches the originator of a request, as identified by the request
      authentication system. There are three ways of matching an originator; by
      user, group, or service account.

      **parameters**

      * **kind** ``str`` - Required
      * **group** ``Optional[GroupSubject]`` - 
      * **serviceAccount** ``Optional[ServiceAccountSubject]`` - 
      * **user** ``Optional[UserSubject]`` - 
    """
    kind: 'str'
    group: 'Optional[GroupSubject]' = None
    serviceAccount: 'Optional[ServiceAccountSubject]' = None
    user: 'Optional[UserSubject]' = None


@dataclass
class UserSubject(DictMixin):
    """UserSubject holds detailed information for user-kind subject.

      **parameters**

      * **name** ``str`` - `name` is the username that matches, or "*" to match all usernames. Required.
    """
    name: 'str'





# autogenerated module
from typing import List, Optional

from ._schema import dataclass, field, DictMixin

from . import meta_v1
from . import util_intstr


@dataclass
class IPBlock(DictMixin):
    """IPBlock describes a particular CIDR (Ex. "192.168.1.1/24","2001:db9::/64")
      that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The
      except entry describes CIDRs that should not be included within this rule.

      **parameters**

      * **cidr** ``str`` - CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24"
        or "2001:db9::/64"
      * **except_** ``Optional[List[str]]`` - Except is a slice of CIDRs that should not be included within an IP Block
        Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be
        rejected if they are outside the CIDR range
    """
    cidr: 'str'
    except_: 'Optional[List[str]]' = field(metadata={"json": "except"}, default=None)


@dataclass
class NetworkPolicy(DictMixin):
    """NetworkPolicy describes what network traffic is allowed for a set of Pods

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - Standard object's metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
      * **spec** ``Optional[NetworkPolicySpec]`` - Specification of the desired behavior for this NetworkPolicy.
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[NetworkPolicySpec]' = None


@dataclass
class NetworkPolicyEgressRule(DictMixin):
    """NetworkPolicyEgressRule describes a particular set of traffic that is allowed
      out of pods matched by a NetworkPolicySpec's podSelector. The traffic must
      match both ports and to. This type is beta-level in 1.8

      **parameters**

      * **ports** ``Optional[List[NetworkPolicyPort]]`` - List of destination ports for outgoing traffic. Each item in this list is
        combined using a logical OR. If this field is empty or missing, this rule
        matches all ports (traffic not restricted by port). If this field is present
        and contains at least one item, then this rule allows traffic only if the
        traffic matches at least one port in the list.
      * **to** ``Optional[List[NetworkPolicyPeer]]`` - List of destinations for outgoing traffic of pods selected for this rule.
        Items in this list are combined using a logical OR operation. If this field is
        empty or missing, this rule matches all destinations (traffic not restricted
        by destination). If this field is present and contains at least one item, this
        rule allows traffic only if the traffic matches at least one item in the to
        list.
    """
    ports: 'Optional[List[NetworkPolicyPort]]' = None
    to: 'Optional[List[NetworkPolicyPeer]]' = None


@dataclass
class NetworkPolicyIngressRule(DictMixin):
    """NetworkPolicyIngressRule describes a particular set of traffic that is allowed
      to the pods matched by a NetworkPolicySpec's podSelector. The traffic must
      match both ports and from.

      **parameters**

      * **from_** ``Optional[List[NetworkPolicyPeer]]`` - List of sources which should be able to access the pods selected for this
        rule. Items in this list are combined using a logical OR operation. If this
        field is empty or missing, this rule matches all sources (traffic not
        restricted by source). If this field is present and contains at least one
        item, this rule allows traffic only if the traffic matches at least one item
        in the from list.
      * **ports** ``Optional[List[NetworkPolicyPort]]`` - List of ports which should be made accessible on the pods selected for this
        rule. Each item in this list is combined using a logical OR. If this field is
        empty or missing, this rule matches all ports (traffic not restricted by
        port). If this field is present and contains at least one item, then this rule
        allows traffic only if the traffic matches at least one port in the list.
    """
    from_: 'Optional[List[NetworkPolicyPeer]]' = field(metadata={"json": "from"}, default=None)
    ports: 'Optional[List[NetworkPolicyPort]]' = None


@dataclass
class NetworkPolicyList(DictMixin):
    """NetworkPolicyList is a list of NetworkPolicy objects.

      **parameters**

      * **items** ``List[NetworkPolicy]`` - Items is a list of schema objects.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - Standard list metadata. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """
    items: 'List[NetworkPolicy]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class NetworkPolicyPeer(DictMixin):
    """NetworkPolicyPeer describes a peer to allow traffic from. Only certain
      combinations of fields are allowed

      **parameters**

      * **ipBlock** ``Optional[IPBlock]`` - IPBlock defines policy on a particular IPBlock. If this field is set then
        neither of the other fields can be.
      * **namespaceSelector** ``Optional[meta_v1.LabelSelector]`` - Selects Namespaces using cluster-scoped labels. This field follows standard
        label selector semantics; if present but empty, it selects all namespaces.
        If PodSelector is also set, then the NetworkPolicyPeer as a whole selects the
        Pods matching PodSelector in the Namespaces selected by NamespaceSelector.
        Otherwise it selects all Pods in the Namespaces selected by NamespaceSelector.
      * **podSelector** ``Optional[meta_v1.LabelSelector]`` - This is a label selector which selects Pods. This field follows standard label
        selector semantics; if present but empty, it selects all pods.
        If NamespaceSelector is also set, then the NetworkPolicyPeer as a whole
        selects the Pods matching PodSelector in the Namespaces selected by
        NamespaceSelector. Otherwise it selects the Pods matching PodSelector in the
        policy's own Namespace.
    """
    ipBlock: 'Optional[IPBlock]' = None
    namespaceSelector: 'Optional[meta_v1.LabelSelector]' = None
    podSelector: 'Optional[meta_v1.LabelSelector]' = None


@dataclass
class NetworkPolicyPort(DictMixin):
    """NetworkPolicyPort describes a port to allow traffic on

      **parameters**

      * **port** ``Optional[util_intstr.IntOrString]`` - The port on the given protocol. This can either be a numerical or named port
        on a pod. If this field is not provided, this matches all port names and
        numbers.
      * **protocol** ``Optional[str]`` - The protocol (TCP, UDP, or SCTP) which traffic must match. If not specified,
        this field defaults to TCP.
    """
    port: 'Optional[util_intstr.IntOrString]' = None
    protocol: 'Optional[str]' = None


@dataclass
class NetworkPolicySpec(DictMixin):
    """NetworkPolicySpec provides the specification of a NetworkPolicy

      **parameters**

      * **podSelector** ``meta_v1.LabelSelector`` - Selects the pods to which this NetworkPolicy object applies. The array of
        ingress rules is applied to any pods selected by this field. Multiple network
        policies can select the same set of pods. In this case, the ingress rules for
        each are combined additively. This field is NOT optional and follows standard
        label selector semantics. An empty podSelector matches all pods in this
        namespace.
      * **egress** ``Optional[List[NetworkPolicyEgressRule]]`` - List of egress rules to be applied to the selected pods. Outgoing traffic is
        allowed if there are no NetworkPolicies selecting the pod (and cluster policy
        otherwise allows the traffic), OR if the traffic matches at least one egress
        rule across all of the NetworkPolicy objects whose podSelector matches the
        pod. If this field is empty then this NetworkPolicy limits all outgoing
        traffic (and serves solely to ensure that the pods it selects are isolated by
        default). This field is beta-level in 1.8
      * **ingress** ``Optional[List[NetworkPolicyIngressRule]]`` - List of ingress rules to be applied to the selected pods. Traffic is allowed
        to a pod if there are no NetworkPolicies selecting the pod (and cluster policy
        otherwise allows the traffic), OR if the traffic source is the pod's local
        node, OR if the traffic matches at least one ingress rule across all of the
        NetworkPolicy objects whose podSelector matches the pod. If this field is
        empty then this NetworkPolicy does not allow any traffic (and serves solely to
        ensure that the pods it selects are isolated by default)
      * **policyTypes** ``Optional[List[str]]`` - List of rule types that the NetworkPolicy relates to. Valid options are
        "Ingress", "Egress", or "Ingress,Egress". If this field is not specified, it
        will default based on the existence of Ingress or Egress rules; policies that
        contain an Egress section are assumed to affect Egress, and all policies
        (whether or not they contain an Ingress section) are assumed to affect
        Ingress. If you want to write an egress-only policy, you must explicitly
        specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that
        specifies that no egress is allowed, you must specify a policyTypes value that
        include "Egress" (since such a policy would not include an Egress section and
        would otherwise default to just [ "Ingress" ]). This field is beta-level in
        1.8
    """
    podSelector: 'meta_v1.LabelSelector'
    egress: 'Optional[List[NetworkPolicyEgressRule]]' = None
    ingress: 'Optional[List[NetworkPolicyIngressRule]]' = None
    policyTypes: 'Optional[List[str]]' = None





# autogenerated module
from typing import List, Optional

from ._schema import dataclass, field, DictMixin

from . import meta_v1


@dataclass
class AuditSink(DictMixin):
    """AuditSink represents a cluster level audit sink

      **parameters**

      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ObjectMeta]`` - 
      * **spec** ``Optional[AuditSinkSpec]`` - Spec defines the audit configuration spec
    """
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ObjectMeta]' = None
    spec: 'Optional[AuditSinkSpec]' = None


@dataclass
class AuditSinkList(DictMixin):
    """AuditSinkList is a list of AuditSink items.

      **parameters**

      * **items** ``List[AuditSink]`` - List of audit configurations.
      * **apiVersion** ``Optional[str]`` - APIVersion defines the versioned schema of this representation of an object.
        Servers should convert recognized schemas to the latest internal value, and
        may reject unrecognized values. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
      * **kind** ``Optional[str]`` - Kind is a string value representing the REST resource this object represents.
        Servers may infer this from the endpoint the client submits requests to.
        Cannot be updated. In CamelCase. More info:
        https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
      * **metadata** ``Optional[meta_v1.ListMeta]`` - 
    """
    items: 'List[AuditSink]'
    apiVersion: 'Optional[str]' = None
    kind: 'Optional[str]' = None
    metadata: 'Optional[meta_v1.ListMeta]' = None


@dataclass
class AuditSinkSpec(DictMixin):
    """AuditSinkSpec holds the spec for the audit sink

      **parameters**

      * **policy** ``Policy`` - Policy defines the policy for selecting which events should be sent to the
        webhook required
      * **webhook** ``Webhook`` - Webhook to send events required
    """
    policy: 'Policy'
    webhook: 'Webhook'


@dataclass
class Policy(DictMixin):
    """Policy defines the configuration of how audit events are logged

      **parameters**

      * **level** ``str`` - The Level that all requests are recorded at. available options: None,
        Metadata, Request, RequestResponse required
      * **stages** ``Optional[List[str]]`` - Stages is a list of stages for which events are created.
    """
    level: 'str'
    stages: 'Optional[List[str]]' = None


@dataclass
class ServiceReference(DictMixin):
    """ServiceReference holds a reference to Service.legacy.k8s.io

      **parameters**

      * **name** ``str`` - `name` is the name of the service. Required
      * **namespace** ``str`` - `namespace` is the namespace of the service. Required
      * **path** ``Optional[str]`` - `path` is an optional URL path which will be sent in any request to this
        service.
      * **port** ``Optional[int]`` - If specified, the port on the service that hosting webhook. Default to 443 for
        backward compatibility. `port` should be a valid port number (1-65535,
        inclusive).
    """
    name: 'str'
    namespace: 'str'
    path: 'Optional[str]' = None
    port: 'Optional[int]' = None


@dataclass
class Webhook(DictMixin):
    """Webhook holds the configuration of the webhook

      **parameters**

      * **clientConfig** ``WebhookClientConfig`` - ClientConfig holds the connection parameters for the webhook required
      * **throttle** ``Optional[WebhookThrottleConfig]`` - Throttle holds the options for throttling the webhook
    """
    clientConfig: 'WebhookClientConfig'
    throttle: 'Optional[WebhookThrottleConfig]' = None


@dataclass
class WebhookClientConfig(DictMixin):
    """WebhookClientConfig contains the information to make a connection with the
      webhook

      **parameters**

      * **caBundle** ``Optional[str]`` - `caBundle` is a PEM encoded CA bundle which will be used to validate the
        webhook's server certificate. If unspecified, system trust roots on the
        apiserver are used.
      * **service** ``Optional[ServiceReference]`` - `service` is a reference to the service for this webhook. Either `service` or
        `url` must be specified.
        If the webhook is running within the cluster, then you should use `service`.
      * **url** ``Optional[str]`` - `url` gives the location of the webhook, in standard URL form
        (`scheme://host:port/path`). Exactly one of `url` or `service` must be
        specified.
        The `host` should not refer to a service running in the cluster; use the
        `service` field instead. The host might be resolved via external DNS in some
        apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would
        be a layering violation). `host` may also be an IP address.
        Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless
        you take great care to run this webhook on all hosts which run an apiserver
        which might need to make calls to this webhook. Such installs are likely to be
        non-portable, i.e., not easy to turn up in a new cluster.
        The scheme must be "https"; the URL must begin with "https://".
        A path is optional, and if present may be any string permissible in a URL. You
        may use the path to pass an arbitrary string to the webhook, for example, a
        cluster identifier.
        Attempting to use a user or basic auth e.g. "user:password@" is not allowed.
        Fragments ("#...") and query parameters ("?...") are not allowed, either.
    """
    caBundle: 'Optional[str]' = None
    service: 'Optional[ServiceReference]' = None
    url: 'Optional[str]' = None


@dataclass
class WebhookThrottleConfig(DictMixin):
    """WebhookThrottleConfig holds the configuration for throttling events

      **parameters**

      * **burst** ``Optional[int]`` - ThrottleBurst is the maximum number of events sent at the same moment default
        15 QPS
      * **qps** ``Optional[int]`` - ThrottleQPS maximum number of batches per second default 10 QPS
    """
    burst: 'Optional[int]' = None
    qps: 'Optional[int]' = None


